"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
/**
 * @param config - A playwright configuration object.
 * @returns A teardown function.
 *
 * @public
 * @example
 * An example demonstrating use of environment variables and temporary folder:
 * ```
 * import rimraf from 'rimraf';
 *
 * async function setup(config: FullConfig) {
 *  process.env.FOO = 'some data';
 *  process.env.BAR = JSON.stringify({ some: 'data' });
 *  return async function teardown() {
 *    delete process.env.FOO;
 *    delete process.env.BAR;
 *    const tmpDirPath = path.join(os.tmpdir(), 'tmp-folder');
 *    rimraf(tmpDirPath, console.log);
 *   };
 * }
 * ```
 */
function setup(config) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        return function teardown() {
            return tslib_1.__awaiter(this, void 0, void 0, function* () { });
        };
    });
}
exports.default = setup;
