"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.delayedResolve = void 0;
const tslib_1 = require("tslib");
/**
 * Delayed resolve utility.
 *
 * @example
 * ```ts
 * test('delayed resolve', async () => {
 *   const mockAPI = delayedResolve({ foo: 'bar' }, 2_000);
 *   const result = await mockAPI();
 * });
 * ```
 * @param result - The result of the promise.
 * @param duration - An optional duration in milliseconds. Defaults to 500.
 * @public
 */
const delayedResolve = (result, duration = 500) => () => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
    yield new Promise((resolve) => {
        setTimeout(resolve, duration);
    });
    return result;
});
exports.delayedResolve = delayedResolve;
