import { suite, test, uvu } from 'uvu';
import * as assert from 'uvu/assert';
/**
 * Timeout utility.
 *
 * @example A promise that never ends.
 * ```ts
 * test(
 *   'should fail',
 *   timeout(async () => {
 *     await new Promise(() => {});
 *     assert.ok(true);
 *   }, 5_000),
 * );
 * ```
 *
 * @example A slow API.
 * ```ts
 * test(
 *   'should fail',
 *   timeout(async () => {
 *     const slowMockAPI = delayedResolve({ foo: 'bar' }, 4_000);
 *     await slowMockAPI();
 *     assert.unreachable('should have timed out');
 *   }, 2_000),
 * );
 * ```
 *
 * @param callback - The async test function.
 * @param duration - An optional duration in milliseconds. Defaults to 5_000.
 * @public
 */
declare const timeout: (callback: (context: any) => Promise<any>, duration?: number) => (context: any) => Promise<any>;
/**
 * UVU assert, suite, test and uvu itself
 * @public
 */
export { assert, suite, test, uvu, timeout };
//# sourceMappingURL=uvu.d.ts.map