import { __awaiter } from "tslib";
import { chromium, test as base } from '@playwright/test';
import { getPort } from 'portfinder-sync';
export { expect } from '@playwright/test';
export { test as base } from '@playwright/test';
export { playAudit } from 'playwright-lighthouse';
const DEFAULT_PORT = 5030;
const defaultPackageConfig = {
    API_HOST: process.env.API_HOST,
    DEFAULT_USER: process.env.DEFAULT_USER,
    DEFAULT_PASSWORD: process.env.DEFAULT_PASSWORD,
    PORT: Number(process.env.PORT || DEFAULT_PORT),
};
export const defaultAuditThresholds = {
    performance: 20,
    accessibility: 80,
    'best-practices': 80,
    seo: 50,
    pwa: 20,
};
/**
 * Playwright test
 * @public
 * @remarks
 * This is just an example playwright test fixture stub. In reality, you will likely create a custom
 * fixture for your e2e tests depending on the needs of your app or micro frontend.
 */
export const test = base.extend({
    config: [defaultPackageConfig, { option: true, scope: 'worker', timeout: 60000 }],
    port: [
        ({ config }, use) => __awaiter(void 0, void 0, void 0, function* () {
            const port = getPort((config === null || config === void 0 ? void 0 : config.PORT) || process.env.PORT || defaultPackageConfig.PORT);
            yield use(port);
        }),
        { scope: 'worker' }, // option: true
    ],
    browser: [
        ({ port }, use) => __awaiter(void 0, void 0, void 0, function* () {
            const browser = yield chromium.launch({
                args: [`--remote-debugging-port=${port}`],
            });
            yield use(browser);
        }),
        { scope: 'worker' },
    ],
    audit: [defaultAuditThresholds, { option: true, scope: 'worker' }], // TODO: These are not being used from other test setups extending this.
});
// Perhaps we keen extending the test up the package chain... spread the mf tests into our app test
// const test2 = test.extend<{ foo: boolean }>({
//   foo: [true, { option: true }],
// });
//
// a('lighthouse audit', async ({ foo, page }) => {
//
// });
